@@ -1,7 +1,8 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*- */
 /*
  * Copyright (C) 2002 CodeFactory AB
  * Copyright (C) 2002 Mikael Hallendal <micke@imendio.com>
+ * Copyright (C) 2005-2008 Imendio AB
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -22,12 +23,14 @@
 #ifndef __DH_BASE_H__
 #define __DH_BASE_H__
 
-#include <glib-object.h>
-#include <gtk/gtkwidget.h>
+#include <gtk/gtk.h>
+
+#include "dh-book-manager.h"
+
+G_BEGIN_DECLS
 
 typedef struct _DhBase      DhBase;
 typedef struct _DhBaseClass DhBaseClass;
-typedef struct _DhBasePriv  DhBasePriv;
 
 #define DH_TYPE_BASE         (dh_base_get_type ())
 #define DH_BASE(o)           (G_TYPE_CHECK_INSTANCE_CAST ((o), DH_TYPE_BASE, DhBase))
@@ -36,25 +39,24 @@ typedef struct _DhBasePriv  DhBasePriv;
 #define DH_IS_BASE_CLASS(k)  (G_TYPE_CHECK_CLASS_TYPE ((k), DH_TYPE_BASE))
 #define DH_BASE_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), DH_TYPE_BASE, DhBaseClass))
 
-
 struct _DhBase {
-        GObject     parent;
-        
-        DhBasePriv *priv;
+        GObject parent_instance;
 };
 
 struct _DhBaseClass {
         GObjectClass parent_class;
 };
 
-GType            dh_base_get_type       (void);
-DhBase *         dh_base_new            (void);
+GType          dh_base_get_type                        (void) G_GNUC_CONST;
+DhBase *       dh_base_get                             (void);
+DhBase *       dh_base_new                             (void);
+GtkWidget *    dh_base_new_window                      (DhBase *base);
+GtkWidget *    dh_base_new_assistant                   (DhBase *base);
+GtkWidget *    dh_base_get_window                      (DhBase *base);
+GtkWidget *    dh_base_get_window_on_current_workspace (DhBase *base);
+DhBookManager *dh_base_get_book_manager                (DhBase *base);
+void           dh_base_quit                            (DhBase *base);
 
-GtkWidget *      dh_base_new_window     (DhBase      *base);
-
-GNode *          dh_base_get_book_tree  (DhBase      *base);
-GList *          dh_base_get_keywords   (DhBase      *base);
-
-GSList *         dh_base_get_windows    (DhBase      *base);
+G_END_DECLS
 
 #endif /* __DH_BASE_H__ */
